@@ -1,7 +1,8 @@
 from iconservice import *
 from .IRC2 import IRC2
+from ..access.roles import Roles
 
-class IRC2Mintable(IRC2):
+class IRC2Mintable(IRC2, Roles):
 	'''
 	Implementation of IRC2Mintable
 	'''
