@@ -2,6 +2,7 @@ from iconservice import *
 from .IRC2 import *
 from ..utils.checks import *
 from ..utils.pausable import *
+from ..access.roles import Roles
 
 class AlreadyPausedException(Exception):
 	pass
@@ -9,7 +10,7 @@ class AlreadyPausedException(Exception):
 class AlreadyUnpausedException(Exception):
 	pass
 
-class IRC2Pausable(IRC2):
+class IRC2Pausable(IRC2, Roles):
 
 	@eventlog(indexed=1)
 	def Paused(self, status:bool):
@@ -21,14 +22,14 @@ class IRC2Pausable(IRC2):
 
 	@external
 	@whenNotPaused
-	@only_owner
+	@only_pauser
 	def pause(self):
 		self._paused.set(True)
 		self.Paused(True)
 
 	@external
 	@whenPaused
-	@only_owner
+	@only_pauser
 	def unpause(self):
 		self._paused.set(False)
 		self.Paused(False)
